Material resource
{
	MaterialType _type = Blended;
	VideoProgram _passes
	[ 
		"normal"
	]
}

VideoProgram normal
{
	VertexLayout _vertexLayout = "MeshLayout\TerrainDecalLayout.rsc";
	VertexProgram _vertexProgram = "vs";
	PixelProgram _pixelProgram = "ps";
	RenderState _renderState = "Material\TerrainDecal\TerrainDecalMaterial.rsc:rs";
}

VertexProgram vs
{
	VertexLayout _input = "MeshLayout/TerrainDecalLayout.rsc";
	String _includes
	[
		"Material/Instancing.hlsl"
		"Material/Lighting.hlsl"
	]

	Output _outputs 
	[
		{ String _type = "float4"; String _name = "position";		Usage _usage = Position;			int _index = 0; }
		{ String _type = "float4"; String _name = "texcoord";		Usage _usage = TextureCoordinate;	int _index = 0; }
		{ String _type = "float3"; String _name = "texcoord2";		Usage _usage = TextureCoordinate;	int _index = 1; }
		{ String _type = "float3"; String _name = "lightFog";		Usage _usage = TextureCoordinate;	int _index = 2; }
		{ String _type = "float3"; String _name = "normal";			Usage _usage = TextureCoordinate;	int _index = 3; }
	]

	String _functions
	[
		"
		void Common(float4x4 localToWorld, float4 position, float3 normal, float4 texcoord, out float3 worldPosition, out float4 outputPosition,
			out float4 outputTexcoord, out float3 lightFog, out float3 outNormal, out float3 outTexcoord2)
		{
			position.z /= 256.0;
			worldPosition = mul((float3x4)localToWorld, float4(position.xyz, 1.0));
			outputPosition = mul(gc_worldToProjection, float4(worldPosition, 1.0));
	
			normal = normalize(normal * 2 - 1);
	
			lightFog = GetLightingFog(normal, outputPosition.z);
	
			outputTexcoord = texcoord / 4096.0;
			outNormal = normal * normal * normal * normal;
			outTexcoord2 = position / 16.0;
		}
		"
	]

	Variant _variants
	[
		{
			String _text = "
				float4x4 localToWorld = GetLocalToWorld(0);
				float3 worldPosition;
				Common(localToWorld, input.position, input.normal, input.texcoord, worldPosition, output.position, output.texcoord, 
					output.lightFog, output.normal, output.texcoord2);
			";
		}
		{
			Output _outputs 
			[
				{ String _type = "float4"; String _name = "shadowProjection";	Usage _usage = TextureCoordinate;	int _index = 4; }
			]
			String _text = "
				float4x4 localToWorld = GetLocalToWorld(0);
				float3 worldPosition;
				Common(localToWorld, input.position, input.normal, input.texcoord, worldPosition, output.position, output.texcoord, 
					output.lightFog, output.normal, output.texcoord2);
				output.shadowProjection = mul(lc_shadowProjection0, float4(worldPosition, 1.0f));
			";
		}
		{
			Output _outputs 
			[
				{ String _type = "float4"; String _name = "shadowProjection";	Usage _usage = TextureCoordinate;	int _index = 4; }
			]
			String _text = "
				float4x4 localToWorld = GetLocalToWorld(0);
				float3 worldPosition;
				Common(localToWorld, input.position, input.normal, input.texcoord, worldPosition, output.position, output.texcoord, 
					output.lightFog, output.normal, output.texcoord2);
				output.shadowProjection = mul(lc_shadowProjection0, float4(worldPosition, 1.0f));
			";
		}
		{
			Output _outputs 
			[
				{ String _type = "float4"; String _name = "shadowProjection";	Usage _usage = TextureCoordinate;	int _index = 4; }
			]
			String _text = "
				float4x4 localToWorld = GetLocalToWorld(0);
				float3 worldPosition;
				Common(localToWorld, input.position, input.normal, input.texcoord, worldPosition, output.position, output.texcoord, 
					output.lightFog, output.normal, output.texcoord2);
				output.shadowProjection = mul(lc_shadowProjection0, float4(worldPosition, 1.0f));
			";
		}
	]
}

PixelProgram ps
{
	VertexProgram _input = "vs";
	String _includes
	[
		"Material/Texture.hlsl"
		"Material/Shadows.hlsl"
	]

	Texture _textureList
	[
		{ bool _2d = true;	String _name = "diffuse";	int _bindIndex = 0;	bool _exposed = true; }
		{ bool _2d = true;	String _name = "snow";		int _bindIndex = 1;	bool _exposed = true; }
		{ bool _2d = true;	String _name = "blend";		int _bindIndex = 2;	bool _exposed = true; }
		{ bool _2d = true;	String _name = "shadowMap";	int _bindIndex = 5;	bool _exposed = false; bool _shadowMap = true; }
	]

	String _functions
	[
		"
		float4 GetColor(float4 texcoord, float3 lightFog, float3 normal, float3 position, float shadow)
		{
			float4 diff = Sample2D(diffuse, diffusesampler, texcoord.xy);
			float4 sno = Sample2D(snow, snowsampler, texcoord.xy);
	
			float4 blendX = Sample2D(blend, blendsampler, position.yz);
			float4 blendY = Sample2D(blend, blendsampler, position.xz);
			float4 blendZ = Sample2D(blend, blendsampler, texcoord.yx);

			float3 na = abs(normal);
			float3 blend = blendX * na.x + blendY * na.y + blendZ * na.z;
			diff.xyz = lerp(blend, diff.xyz, diff.w);
			diff.xyz = lerp(diff.xyz, sno.xyz, normal.z * pc_userPosition.x);
	    
			float4 output; 
			output.xyz = ComputeLighting(lightFog, diff.xyz, shadow);
			output.w = blendZ.w; 
	
			return output;
		}
		"
	]

	Variant _variants
	[
		{
			String _text = "output.color = GetColor(input.texcoord, input.lightFog, input.normal, input.texcoord2, 1);";
		}
		{
			String _text = "output.color = GetColor(input.texcoord, input.lightFog, input.normal, input.texcoord2, GetShadowLow(input.shadowProjection));";
		}
		{
			String _text = "output.color = GetColor(input.texcoord, input.lightFog, input.normal, input.texcoord2, GetShadowMedium(input.shadowProjection, pc_texelSize.x));";
		}
		{
			String _text = "output.color = GetColor(input.texcoord, input.lightFog, input.normal, input.texcoord2, GetShadowHigh(input.shadowProjection, pc_texelSize.x));";
		}
	]
}
